@@ -6,15 +6,15 @@ from syst3m.classes import defaults
 
 # input.
 _input_ = input
-def input(message, yes_no=False):
+def input(message, yes_no=False, check=False):
+	message = color.fill(message)
 	if len(message) > 0 and message[0].upper() != message[0]: message = String(message).capitalized_word()
-	msg = color.fill(message)
 	if yes_no:
 		while True:
 			if len(message) > 0 and message[len(message)-1] == " ": message = message[:-1]
 			elif len(message) > 0 and message[len(message)-1] == ".": message = message[:-1]
 			else: break
-		value = _input_(message+" (y/n) ")
+		value = _input_(message+" (y/n): ")
 		if value in ["yes", 'y', "YES", "Y"]:
 			return True
 		else:
@@ -24,9 +24,81 @@ def input(message, yes_no=False):
 			if len(message) > 0 and message[len(message)-1] == " ": message = message[:-1]
 			elif len(message) > 0 and message[len(message)-1] == ":": message = message[:-1]
 			else: break
-		return _input_(message+": ")
+		value = _input_(message+": ")
+		if check:
+			if input(f"({value}) correct?", yes_no=True):
+				return value
+			else:
+				return None
+		else:
+			return value
 
-# execute.
+# execute & output.
+class Output(ResponseObject):
+	def __init__(self, 
+		# the success message (param #1).
+		message=None,
+		# the attributes (param #2).
+		attributes={},
+		# the error message (param #3).
+		error=None,
+	):
+		dictionary = {
+			"success":error == None,
+			"message":message,
+			"error":error,
+		}
+		for key,value in attributes.items():
+			dictionary[key] = value
+		ResponseObject.__init__(self, dictionary)
+		if self.success:
+			self.str = str(self.output)
+		else:
+			self.str = str(self.error)
+	def __len__(self):
+		return len(self.str)
+	def __str__(self):
+		return str(self.str)
+	def __bool__(self):
+		return bool(self.success)
+	# support default iteration.
+	def __iter__(self):
+		return iter(str(self))
+	# support '==' & '!=' operator.
+	def __eq__(self, dictionary):
+		if isinstance(dictionary, dict):
+			return str(self.sort()) == str(Dictionary(dictionary).sort())
+		elif isinstance(dictionary, Dictionary):
+			return str(self.sort()) == str(dictionary.sort())
+		else:
+			try:
+				return str(self.sort()) == str(dictionary.sort())
+			except:
+				return False
+	def __ne__(self, dictionary):
+		if isinstance(dictionary, dict):
+			return str(self.sort()) != str(Dictionary(dictionary).sort())
+		elif isinstance(dictionary, Dictionary):
+			return str(self.sort()) != str(dictionary.sort())
+		else:
+			try:
+				return str(self.sort()) != str(dictionary.sort())
+			except:
+				return False
+	# support 'in' operator.
+	def __contains__(self, string):
+		if isinstance(path, (list, Array)):
+			for i in string:
+				if i in self.str:
+					return True
+			return False
+		else:
+			return string in self.str
+		#
+	# object instance.
+	def instance(self):
+		return "Output"
+		#
 def execute(
 	# option 1:
 	# the command in str format (str is saved to a script & then executed).
@@ -47,66 +119,6 @@ def execute(
 	# aka expect dict format.
 	serialize=False,
 ):
-	
-	# output class.
-	class Output(ResponseObject):
-		def __init__(self, 
-			# the success message (param #1).
-			message=None,
-			# the attributes (param #2).
-			attributes={},
-			# the error message (param #3).
-			error=None,
-		):
-			dictionary = {
-				"success":error == None,
-				"message":message,
-				"error":error,
-			}
-			for key,value in attributes.items():
-				dictionary[key] = value
-			ResponseObject.__init__(self, dictionary)
-			if self.success:
-				self.str = str(self.output)
-			else:
-				self.str = str(self.error)
-		def __len__(self):
-			return len(self.str)
-		def __str__(self):
-			return str(self.str)
-		def __bool__(self):
-			return bool(self.success)
-		# support default iteration.
-		def __iter__(self):
-			return iter(str(self))
-		# support '==' & '!=' operator.
-		def __eq__(self, dictionary):
-			# new.
-			if isinstance(dictionary, (dict, Dictionary, Output, ResponseObject)):
-				return str(self.sort()) == str(dictionary.sort())
-			else:
-				return self.str == str(dictionary)
-		def __ne__(self, dictionary):
-			# new.
-			if isinstance(dictionary, (dict, Dictionary, Output, ResponseObject)):
-				return str(self.sort()) != str(dictionary.sort())
-			else:
-				return self.str != str(dictionary)
-		# support 'in' operator.
-		def __contains__(self, string):
-			if isinstance(path, (list, Array)):
-				for i in string:
-					if i in self.str:
-						return True
-				return False
-			else:
-				return string in self.str
-			#
-		# object instance.
-		def instance(self):
-			return "Output"
-			#
-
 	# excute.
 	delete = False
 	if path == None:
@@ -264,10 +276,11 @@ class Loader(threading.Thread):
 			time.sleep(0.33)
 	# system functions.
 	def __clean_message__(self, message):
+		message = color.fill(str(message))
 		if message[-len(" ..."):] == " ...": message = message[:-4]
 		if message[-len("."):] == ".": message = message[:-1]
 		if message[0].upper() != message[0]: message = message[1:]+message[0].upper()+message[1:]
-		return color.fill(message)
+		return message
 	def __empty_message__(self, length=len("hello world")):
 		s = ""
 		for i in range(length): s += " "
